/*

  I2C Scanner

  Dele krævet:
  - Arduino Board
  - Modul I2C Interface
  - Kabler

  Biblioteker:
  - Wire.h (Standard i Arduino IDE)

  Programmering af : René Rasmussen
  Webside : www.it-teknolog.dk
  kontakt : renerasmussen@it-teknolog.dk
  Dato : 18 Aug 2019
  Version : v1.0

  Information:
  Programmet scanner I2C adresser fra 1 til 127, sender alle adresser til serial monitoren
  og man kan tilslutte flere moduler med I2C Interface på en gang, programmet kører kun 1 gang
  så man skal starte programmet hver gang men vil scanne et I2C Modul.

  Hvis du har forbedringer eller finder fejl eller mangler er du velkommen til at skrive 
  på ovenstående email. 
  
  Og selvfølgelig gerne ris og ros.
  
*/

#include <Wire.h>                                     // inkludere biblioteket Wire.h

byte scannedAddress;                                  // opret variabel scannedAddress
byte address;                                         // opret variabel address
byte noDeviceFound = 0;                               // opret cariabel noDeviceFound = 0

void setup() {
  Wire.begin();                                       // start kommunikation med Wire
  Serial.begin(9600);                                 // start serial monitor kommunikation

  Serial.println("Scanner efter I2C moduler....");    // print tekst
  Serial.println("-----------------------------");    // print tekst

  for (address = 1 ; address < 127 ; address++) {     // scanner adresser fra 1 til 127

    Wire.beginTransmission(address);                  // start transmission til adresse
    scannedAddress = Wire.endTransmission();          // adressen gemmes i variablen scannedAddress

    if (scannedAddress == 0) {                        // hvis adressen er lig 0
      Serial.print("I2C Modul fundet på adresse : "); // print tekst
      Serial.print("0");                              // print tekst
      Serial.print("x");                              // print tekst
      Serial.println(address, HEX);                   // print adressen i heximal tal

      noDeviceFound++;                                // hvis adressen ikke findes gå til næste
    }
  }
  if (noDeviceFound == 0 ) {                          // findes der ingen adresser 
    Serial.println("Ingen I2C Moduler Fundet......"); // print tekst
  }
}

void loop() {

}
